!-----------------------------------------------------------------------------------!
!                                                                                   !
!                            QUASIATOMIC ORBITAL (QO)                               !
!                                                                                   !
!   Description:  Quasiatomic Wannier Functions in Molecules and Solids             !
!                                                                                   !
!   Author:       Xiaofeng Qian  (MIT, Cambridge, MA, USA)                          !
!                                                                                   !
!   Reference:   "Quasiatomic orbitals for ab initio tight-binding analysis",       !
!                 Xiaofeng Qian, Ju Li, Liang Qi, Cai-Zhuang Wang,                  !
!                 Tzu-Liang Chan, Yong-Xin Yao, Kai-Ming Ho, and Sidney Yip,        !
!                 Physical Review B 78, 245112 (2008)                               !
!                                                                                   !
!   Reference (in BIBTEX format):                                                   !
!                                                                                   !
!     @ARTICLE{QianLQWCYHY08,                                                       !
!          author    = {Qian, Xiaofeng and Li, Ju and Qi, Liang and Wang, C. Z. and !
!                       Chan, T. L. and Yao, Y. X. and Ho, K. M. and Yip, Sidney},  !
!          title     = {Quasiatomic orbitals for ab initio tight-binding analysis}, ! 
!          journal   = {Phys. Rev. B},                                              !
!          year	     = {2008},                                                      !
!          volume    = {78},                                                        !
!          pages     = {245112}                                                     !
!     }                                                                             !
!                                                                                   !
!   Please cite the above reference if you use the code or part of the code.        !  
!                                                                                   !
!   Copyright (C) 2009 Xiaofeng Qian                                                !
!                                                                                   !
!   This file is distributed under the terms of the                                 !
!   GNU General Public License. See the file `License'                              !
!   in the root directory of the present distribution,                              !
!   or http://www.gnu.org/copyleft/gpl.txt .                                        !
!                                                                                   !
!-----------------------------------------------------------------------------------!
!
PROGRAM QO
!
#include "f_defs.h" 
  USE io_global,  ONLY : stdout, ionode, ionode_id
  USE kinds,      ONLY : DP
  USE global_version,   ONLY : version_number
  USE io_files,         ONLY : nd_nmbr, prefix, tmp_dir, trimcheck
  USE mp_global,        ONLY : mp_startup
  USE environment,      ONLY : environment_start
  USE QO_module
  
  implicit none
  character (len=9)  :: code='QO'  
#if defined __INTEL
  ! ... Intel compilers v .ge.8 allocate a lot of stack space
  ! ... Stack limit is often small, thus causing SIGSEGV and crash
  call remove_stack_limit ( )
#endif
  
  call init_clocks( .true. )
  
  call start_clock( code )
  
  ! ... and begin with the initialization part
#ifdef __PARA
  CALL mp_startup ( )
#endif
  CALL environment_start ( code )
  !
  call QO_readin()

  ! read ground state wavefunctions
  call read_file ( )
  call QO_openfil ( )
  
  
  call QO_initialize_pp()  
  call QO_readcards()
  
  call QO_initialize_atomicwfc()
  
  call QO_initialize
  call QO_setup_dft()
  
  if (QO_flag_construction) then
     call QO_construction()     
     call QO_tightbinding()     
     call QO_write2netcdf()
  end if
  
  
  if ( QO_flag_output_orbital ) then
     if (QO_plot_number_of_kpoints <= 0) then
        call QO_output_orbital()
     else
        call QO_output_orbital_kpoints()
     end if
  end if
  
  
  call QO_finalize()     
  !!  endif
  
  ! print timings and stop the code
  call print_clock_QO
  call stop_code( .TRUE. )
  
  STOP
  
END PROGRAM QO


